==> humhub-1.14.5.tar.gz: humhub-1.14.5/protected/humhub/modules/content/messages/nb-NO/base.php <==
<?php

return [
    '<strong>Confirm</strong> post deletion' => '<strong>Bekreft</strong> sletting av innlegg',
    '<strong>Move</strong> content' => '<strong>Flytt</strong> innhold',
    '<strong>Permalink</strong> to this post' => '@@@@',
    'Activated' => 'Aktivert',
    'Add a member to notify' => 'Legg til en følger',
    'Archived' => 'Arkivert',
    'Back to stream' => 'Tilbake til nyhetsstrøm',
    'Cancel' => 'Avbryt',
    'Cancel Edit' => 'Avbryt redigering',
    'Change to "Private"' => 'Gjør privat',
    'Change to "Public"' => 'Gjør offentlig',
    'Configure' => 'Konfigurer',
    'Confirm' => 'Bekreft',
    'Content' => 'Innhold',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Innholdstegn med ugyldig contentcontainer_id tildelt.',
    'Content has been moved to {spacename}' => 'Innholdet har blitt flyttet til gruppen {spacename}',
    'Could not find requested content!' => 'Kunne ikke finne ønsket innhold!',
    'Created by me' => 'Opprettet av meg',
    'Creation time' => 'Opprettet',
    'Delete' => 'Slett',
    'Deleted' => 'Slettet',
    'Do you really want to delete this post? All likes and comments will be lost!' => 'Ønsker du virkelig og slette dette innlegget? Alle likes og kommentarer vil bli tapt!',
    'Edit' => 'Rediger',
    'Enable' => 'Aktiver',
    'Filter' => 'Filter',
    'I\'m involved' => 'Der jeg deltar',
    'Invalid content id given!' => 'Ugyldig innholds-ID angitt!',
    'Invalid request method!' => 'Feil.',
    'Invalid space selection.' => 'Ugyldig valgt gruppe.',
    'Last update' => 'Siste oppdatering',
    'Load more' => 'Last inn mer',
    'Move content' => 'Flytt innhold',
    'Move to archive' => 'Flytt til arkiv',
    'No matches with your selected filters!' => 'Ingen treff med dine valgte filtere!',
    'None' => 'Ingen',
    'Nothing here yet!' => 'Ingen ting her enda!',
    'Notify members' => 'Varsle medlemmer',
    'Permalink' => '@@@@',
    'Pin to top' => 'Pin til toppen',
    'Pinned' => 'Låst',
    'Private' => 'Privat',
    'Public' => 'Offentlig',
    'Submit' => 'Send',
    'Tag' => 'Stikkord',
    'Target Space' => 'Målgruppe',
    'The author of this content is not allowed to create private content within the selected space.' => 'Forfatteren av dette innholdet kan ikke skjult offentlig  innhold på den aktuelle gruppen.',
    'The author of this content is not allowed to create public content within the selected space.' => 'Forfatteren av dette innholdet kan ikke publisere offentlig  innhold på den aktuelle gruppen.',
    'The content can\'t be moved to its current space.' => 'Innholdet kan ikke flyttes til gjeldene gruppe.',
    'The content has been archived.' => 'Innholdet er arkivert.',
    'The content has been deleted.' => 'Innholdet er slettet.',
    'The content has been unarchived.' => 'Innholdet er hentet tilbake fra arkivet.',
    'The given name is already in use.' => 'Oppgitt navn er allerede i bruk.',
    'The module {moduleName} is not enabled on the selected target space.' => 'Modulen {moduleName} er ikke aktivert for den aktuelle gruppen.',
    'This action is disabled!' => 'Denne handlingen er ikke tilgjengelig.',
    'This content type can\'t be moved due to a missing module-id setting.' => 'Denne innholdstypen kan ikke flyttes på grunn av en manglende modul-ID-innstilling.',
    'This content type can\'t be moved.' => 'Innholdet kan ikke flyttes',
    'This space is archived.' => 'Denne gruppen er arkivert',
    'This space is not visible!' => 'Denne gruppen er ikke synlig',
    'Topics' => 'Emne',
    'Turn off notifications' => 'Skru av varsler',
    'Turn on notifications' => 'Skru på varsler',
    'Unarchive' => 'Ta ut fra arkiv',
    'Unpin' => 'Fjern pin',
    'Updated' => 'Oppdatert',
    'With attachments' => 'Med filvedlegg',
    'You do not have the permission to move this content to the given space.' => 'Du har ikke tillatelse til å flytte dette innholdet til den aktuelle gruppen.',
    'You do not have the permission to move this content.' => 'Du har ikke tillatelse til å flytte dette innholdet.',
    'Your last edit state has been saved!' => 'Din siste redigerte versjon er lagret!',
    'in' => 'i',
    '(Also visible to non-members of this space)' => '',
    '<strong>Delete</strong> content?' => '',
    '<strong>Scheduling</strong> Options' => '',
    'Activate scheduling' => '',
    'Add tag...' => '',
    'Attach Files' => '',
    'Cannot notify the author.' => '',
    'Comments are locked' => '',
    'Comments are unlocked' => '',
    'Create as draft' => '',
    'Created at:' => '',
    'Draft' => '',
    'Hidden' => '',
    'Last updated {time}' => '',
    'Lock comments' => '',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => '',
    'New Updates Available!' => '',
    'No tags found for the given query' => '',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => '',
    'Publish draft' => '',
    'Schedule publication' => '',
    'Scheduled at {dateTime}' => '',
    'Select type...' => '',
    'Specify who can see this content.' => '',
    'The author of this content is not allowed to create this type of content within this space.' => '',
    'The content has been successfully published.' => '',
    'Unlock comments' => '',
    'Visible also to unregistered users' => '',
    'Visible only to you' => '',
    'Visible to all Space members' => '',
    'Visible to all signed in users' => '',
    'Visible to friends of {displayName}' => '',
    'Visible to you and {displayName}' => '',
    'Visible to your friends' => '',
    'You cannot block the space owner!' => '',
    'You cannot block the user of the same container!' => '',
    'You cannot block yourself!' => '',
];

==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/content/messages/nb-NO/base.php <==
<?php

return [
    '<strong>Move</strong> content' => '<strong>Flytt</strong> innhold',
    '<strong>Permalink</strong> to this post' => '@@@@',
    'Activated' => 'Aktivert',
    'Add a member to notify' => 'Legg til en følger',
    'Archived' => 'Arkivert',
    'Back to stream' => 'Tilbake til nyhetsstrøm',
    'Cancel' => 'Avbryt',
    'Cancel Edit' => 'Avbryt redigering',
    'Change to "Private"' => 'Gjør privat',
    'Change to "Public"' => 'Gjør offentlig',
    'Configure' => 'Konfigurer',
    'Confirm' => 'Bekreft',
    'Content' => 'Innhold',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Innholdstegn med ugyldig contentcontainer_id tildelt.',
    'Content has been moved to {spacename}' => 'Innholdet har blitt flyttet til gruppen {spacename}',
    'Could not find requested content!' => 'Kunne ikke finne ønsket innhold!',
    'Created by me' => 'Opprettet av meg',
    'Creation time' => 'Opprettet',
    'Delete' => 'Slett',
    'Deleted' => 'Slettet',
    'Edit' => 'Rediger',
    'Enable' => 'Aktiver',
    'Filter' => 'Filter',
    'I\'m involved' => 'Der jeg deltar',
    'Invalid content id given!' => 'Ugyldig innholds-ID angitt!',
    'Invalid request method!' => 'Feil.',
    'Invalid space selection.' => 'Ugyldig valgt gruppe.',
    'Last update' => 'Siste oppdatering',
    'Load more' => 'Last inn mer',
    'Move content' => 'Flytt innhold',
    'Move to archive' => 'Flytt til arkiv',
    'No matches with your selected filters!' => 'Ingen treff med dine valgte filtere!',
    'None' => 'Ingen',
    'Nothing here yet!' => 'Ingen ting her enda!',
    'Notify members' => 'Varsle medlemmer',
    'Permalink' => '@@@@',
    'Pin to top' => 'Pin til toppen',
    'Pinned' => 'Låst',
    'Private' => 'Privat',
    'Public' => 'Offentlig',
    'Submit' => 'Send',
    'Tag' => 'Stikkord',
    'Target Space' => 'Målgruppe',
    'The author of this content is not allowed to create private content within the selected space.' => 'Forfatteren av dette innholdet kan ikke skjult offentlig  innhold på den aktuelle gruppen.',
    'The author of this content is not allowed to create public content within the selected space.' => 'Forfatteren av dette innholdet kan ikke publisere offentlig  innhold på den aktuelle gruppen.',
    'The content can\'t be moved to its current space.' => 'Innholdet kan ikke flyttes til gjeldene gruppe.',
    'The content has been archived.' => 'Innholdet er arkivert.',
    'The content has been deleted.' => 'Innholdet er slettet.',
    'The content has been unarchived.' => 'Innholdet er hentet tilbake fra arkivet.',
    'The given name is already in use.' => 'Oppgitt navn er allerede i bruk.',
    'The module {moduleName} is not enabled on the selected target space.' => 'Modulen {moduleName} er ikke aktivert for den aktuelle gruppen.',
    'This action is disabled!' => 'Denne handlingen er ikke tilgjengelig.',
    'This content type can\'t be moved due to a missing module-id setting.' => 'Denne innholdstypen kan ikke flyttes på grunn av en manglende modul-ID-innstilling.',
    'This content type can\'t be moved.' => 'Innholdet kan ikke flyttes',
    'This space is archived.' => 'Denne gruppen er arkivert',
    'This space is not visible!' => 'Denne gruppen er ikke synlig',
    'Topics' => 'Emne',
    'Turn off notifications' => 'Skru av varsler',
    'Turn on notifications' => 'Skru på varsler',
    'Unarchive' => 'Ta ut fra arkiv',
    'Unpin' => 'Fjern pin',
    'Updated' => 'Oppdatert',
    'With attachments' => 'Med filvedlegg',
    'You do not have the permission to move this content to the given space.' => 'Du har ikke tillatelse til å flytte dette innholdet til den aktuelle gruppen.',
    'You do not have the permission to move this content.' => 'Du har ikke tillatelse til å flytte dette innholdet.',
    'Your last edit state has been saved!' => 'Din siste redigerte versjon er lagret!',
    'in' => 'i',
    '(Also visible to non-members of this space)' => '',
    '<strong>Delete</strong> content?' => '',
    '<strong>Scheduling</strong> Options' => '',
    'Activate scheduling' => '',
    'Add tag...' => '',
    'Attach Files' => '',
    'Cannot notify the author.' => '',
    'Comments are locked' => '',
    'Comments are unlocked' => '',
    'Create as draft' => '',
    'Created at:' => '',
    'Do you want to delete this content, including all comments and attachments?<br><br>Please note: If a stream entry was created using a module, the original content that this entry is linked to will also be deleted.' => '',
    'Draft' => '',
    'Hidden' => '',
    'Last updated {time}' => '',
    'Lock comments' => '',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => '',
    'New Updates Available!' => '',
    'No tags found for the given query' => '',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => '',
    'Publish draft' => '',
    'Save as draft' => '',
    'Save scheduling' => '',
    'Schedule publication' => '',
    'Scheduled for {dateTime}' => '',
    'Select type...' => '',
    'Specify who can see this content.' => '',
    'The author of this content is not allowed to create this type of content within this space.' => '',
    'The content cannot be published!' => '',
    'The content has been successfully published.' => '',
    'Unlock comments' => '',
    'Visible also to unregistered users' => '',
    'Visible only to you' => '',
    'Visible to all Space members' => '',
    'Visible to all signed in users' => '',
    'Visible to friends of {displayName}' => '',
    'Visible to you and {displayName}' => '',
    'Visible to your friends' => '',
    'You cannot block the space owner!' => '',
    'You cannot block the user of the same container!' => '',
    'You cannot block yourself!' => '',
];
